<html><head><title>FAQ for the Contacts Manager</title>
<meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" >
<link rel="stylesheet" type="text/css" title="pod_stylesheet" href="/assets/css/local/pod.css">

</head>
<body class='pod'>
<!--
  generated by Local::Pod::Simple::HTML v1.00,
  using Pod::Simple::PullParser v3.13,
  under Perl v5.010001 at Wed Feb 17 04:41:51 2010 GMT.

 If you want to change this HTML document, you probably shouldn't do that
   by changing it directly.  Instead, see about changing the calling options
   to Local::Pod::Simple::HTML, and/or subclassing Local::Pod::Simple::HTML,
   then reconverting this document from the Pod source.
   When in doubt, email the author of Local::Pod::Simple::HTML for advice.
   See 'perldoc Local::Pod::Simple::HTML' for more info.

-->

<!-- start doc -->
<a name='___top' class='dummyTopAnchor' ></a>
<h1><div class="toc_title">FAQ for the Contacts Manager</div></h1>
<h3><div class="toc_toc">Table of contents</div></h3>
<table align="center" summary = "Table of Contents">
<tr><td align="center"><a href="#FAQ_for_the_Contacts_Manager">FAQ for the Contacts Manager</a></td></tr>
<tr><td align="center"><a href="#A_note_about_the_calendars_used_in_reports">A note about the calendars used in reports</a></td></tr>
<tr><td align="center"><a href="#What_does_Broadcast_mean%3F">What does Broadcast mean?</a></td></tr>
<tr><td align="center"><a href="#What_does_%27(Hidden)%27_mean_in_the_broadcast_menu%3F">What does &#39;(Hidden)&#39; mean in the broadcast menu?</a></td></tr>
<tr><td align="center"><a href="#What_does_the_%27-%27_character_mean_in_a_menu%3F">What does the &#39;-&#39; character mean in a menu?</a></td></tr>
</table>
<h1><a class='u' href='#___top' title='click to go to top of document'
name="FAQ_for_the_Contacts_Manager"
>FAQ for the Contacts Manager</a></h1>

<h2><a class='u' href='#___top' title='click to go to top of document'
name="A_note_about_the_calendars_used_in_reports"
>A note about the calendars used in reports</a></h2>

<p>A calendar only works when a day is selected.
You can tell a day is selected by it having a blue background.</p>

<p>Both the From and To calendars default to today&#39;s date.</p>

<p>However,
if you navigate to another month,
you must explicitly select a day by clicking on it.</p>

<p>Lastly,
for the Records report,
the dates are always ignored.</p>

<h2><a class='u' href='#___top' title='click to go to top of document'
name="What_does_Broadcast_mean?"
>What does Broadcast mean?</a></h2>

<p>Broadcast is the difference between private and public contacts.</p>

<p>By setting Broadcast to Public,
you permit other people&#39;s search results to show your contacts.</p>

<p>By setting it to Private,
you stop other people&#39;s search results displaying your contacts.</p>

<p>So,
by this means,
you can keep some or all of your contact information private.</p>

<h2><a class='u' href='#___top' title='click to go to top of document'
name="What_does_&#39;(Hidden)&#39;_mean_in_the_broadcast_menu?"
>What does &#39;(Hidden)&#39; mean in the broadcast menu?</a></h2>

<p>It means the entity has been deleted,
but since entities are not really deleted (in case they need to be recovered),
they are flagged as hidden,
so the search code does not retrieve them.</p>

<h2><a class='u' href='#___top' title='click to go to top of document'
name="What_does_the_&#39;-&#39;_character_mean_in_a_menu?"
>What does the &#39;-&#39; character mean in a menu?</a></h2>

<p>It depends on the menu:</p>

<dl>
<dt><a name="Communication_types:_Any_contact_method,_i.e._no_restriction"
>Communication types: Any contact method,
i.e.
no restriction</a></dt>

<dd>
<dt><a name="Genders:_Either_unknown_(for_people),_or_not_applicable_(for_organizations)"
>Genders: Either unknown (for people),
or not applicable (for organizations)</a></dt>

<dd>
<dt><a name="Occupation_titles:_The_title_is_unknown"
>Occupation titles: The title is unknown</a></dt>

<dd>
<dt><a name="Organization_names:_The_name_is_&#39;-&#39;._This_is_the_special_organization_which_must_always_be_present"
>Organization names: The name is &#39;-&#39;.
This is the special organization which must always be present</a></dt>

<dd>
<dt><a name="Roles:_The_role_is_unknown"
>Roles: The role is unknown</a></dt>

<dd>
<dt><a name="Titles:_The_title_is_unknown"
>Titles: The title is unknown</a></dt>
</dl>

<!-- end doc -->

</body></html>
